import "./App.css";

import { useState } from "react";
import { ReactSortable, ReactSortableProps } from "react-sortablejs";

interface Player {
  id: number;
  name: string;
}

function loadPlayers() {
  const players = [
    "August",
    "Beate",
    "Ceasar",
    "Daedalus",
    "Elli",
    "Ford P.",
    "Gabriel",
    "Hugo",
    "Ivar Johansson",
    "Jürgen Gordon Malinauskas",
    "Karsten Uwe Kalinowski",
  ].map((v, i) => {
    return { id: i, name: v } as Player;
  });
  return players;
}

type PlayerListProps = Partial<ReactSortableProps<any>> & {
  orderedList?: boolean;
};

function PlayerList(props: PlayerListProps) {
  return (
    <ReactSortable {...props} animation={200}>
      {props.list?.map((item, index) => (
        <div key={item.id} className="item">
          {props.orderedList ? index + 1 + ". " + item.name : item.name}
        </div>
      ))}
    </ReactSortable>
  );
}

function App() {
  const players = loadPlayers();
  const [user, setUser] = useState<Player[]>([]);
  const [playersLeft, setPlayersLeft] = useState<Player[]>([]);
  const [playersMiddle, setPlayersMiddle] = useState<Player[]>(players);
  const [playersRight, setPlayersRight] = useState<Player[]>([]);

  function handleSubmit() {
    if (user.length < 1) {
      alert("who are you?");
      return;
    }
    for (const u of user) {
      console.log(u.name);
    }
  }

  return (
    <>
      <img alt="logo" height="128px" src="logo.svg" />
      <h1>cutt</h1>
      <span className="grey">cool ultimate team tool</span>
      <div className="box user">
        <h2>who are you?</h2>
        <PlayerList
          list={user}
          setList={setUser}
          group={{
            name: "shared",
            put: function (to) {
              return to.el.children.length < 1;
            },
          }}
          className="dragbox"
        />
      </div>
      <div className="container">
        <div className="box">
          <h2>😬</h2>
          <PlayerList
            list={playersRight}
            setList={setPlayersRight}
            group={"shared"}
            className="dragbox"
            orderedList
          />
        </div>
        <div className="box">
          <h2>🤷</h2>
          <PlayerList
            list={playersMiddle}
            setList={setPlayersMiddle}
            group={"shared"}
            className="middle dragbox"
          />
        </div>
        <div className="box">
          <h2>😍</h2>
          <PlayerList
            list={playersLeft}
            setList={setPlayersLeft}
            group={"shared"}
            className="dragbox"
            orderedList
          />
        </div>
      </div>

      <button
        onClick={() =>
          handleSubmit(user, playersLeft, playersMiddle, playersRight)
        }
      >
        submit
      </button>
      <footer>
        <p className="grey">
          something not working? message <a href="https://t.me/x0124816">me</a>.
        </p>
      </footer>
    </>
  );
}

export default App;
